@@ -1,61 +1,43 @@
-from lxml.html.clean import clean_html
 import os
 import frontmatter
 import yaml
-from paka import cmark
+from kart.utils import RawMarkup
 
 
-class DefaultPostMiner:
-    def __init__(self, collection_name="posts", model=None, location="collections"):
-        self.model = model
-        self.collection_name = collection_name
-        self.location = location
-
+class Miner:
     def collect(self):
-        self.data = []
-        for file in os.listdir(os.path.join(self.location, self.collection_name)):
-            with open(
-                os.path.join(self.location, self.collection_name, file), "r"
-            ) as f:
-                metadata, content = frontmatter.parse(f.read())
-                object = metadata
-                if "draft" in object.keys():
-                    if object["draft"]:
-                        continue
-                object["slug"] = file.split(".")[0]
-                object["content"] = cmark.to_html(content)
-                object["short_content"] = clean_html(object["content"][:1000])
-                self.data.append(object)
-        self.data.sort(key=lambda x: x["date"])
-        self.data.reverse()
-        return {self.collection_name: self.data}
+        pass
 
 
-class DefaultCollectionMiner:
+class DefaultCollectionMiner(Miner):
     def __init__(self, collection_name, model=None, location="collections"):
         self.model = model
         self.collection_name = collection_name
         self.location = location
 
+    def collect_single_file(self, filename, file_location):
+        with open(file_location, "r") as f:
+            metadata, content = frontmatter.parse(f.read())
+            object = metadata
+            object["slug"] = filename.split(".")[0]
+            object["content"] = RawMarkup(content)
+            if "draft" in object.keys():
+                if object["draft"]:
+                    return False
+            return object
+
     def collect(self):
         self.data = []
-        for file in os.listdir(os.path.join(self.location, self.collection_name)):
-            with open(
-                os.path.join(self.location, self.collection_name, file), "r"
-            ) as f:
-                metadata, content = frontmatter.parse(f.read())
-                object = metadata
-                object["slug"] = file.split(".")[0]
-                object["content"] = cmark.to_html(content)
+        working_dir = os.path.join(self.location, self.collection_name)
+        for filename in os.listdir(working_dir):
+            file_location = os.path.join(working_dir, filename)
+            object = self.collect_single_file(filename, file_location)
+            if object:
                 self.data.append(object)
-        try:
-            self.data.sort(key=lambda x: x["index"])
-        except Exception:
-            pass
         return {self.collection_name: self.data}
 
 
-class DefaultPageMiner:
+class DefaultPageMiner(Miner):
     def __init__(self, location="pages"):
         self.location = location
 
@@ -65,12 +47,12 @@ class DefaultPageMiner:
             with open(os.path.join(self.location, file), "r") as f:
                 metadata, content = frontmatter.parse(f.read())
                 object = metadata
-                object["content"] = cmark.to_html(content)
+                object["content"] = RawMarkup(content)
                 self.data[file.split(".")[0]] = object
         return {"pages": self.data}
 
 
-class DefaultDataMiner:
+class DefaultDataMiner(Miner):
     def __init__(self, location="data"):
         self.location = location
 
